@@ -1,7 +1,7 @@
 package Text::ANSITable;
 
-our $DATE = '2015-10-21'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $DATE = '2015-10-22'; # DATE
+our $VERSION = '0.46'; # VERSION
 
 use 5.010001;
 use Carp;
@@ -268,9 +268,7 @@ sub BUILD {
     }
 
     unless (defined $self->{wide}) {
-        require Module::Path::More;
-        $self->{wide} = Module::Path::More::module_path(
-            module => 'Text::ANSI::WideUtil') ? 1:0;
+        $self->{wide} = eval { require Text::ANSI::WideUtil; 1 } ? 1:0;
     }
     require Text::ANSI::NonWideUtil;
     $self->{_func_add_color_resets} = \&Text::ANSI::NonWideUtil::ta_add_color_resets;
@@ -1673,7 +1671,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.45 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2015-10-21.
+This document describes version 0.46 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2015-10-22.
 
 =head1 SYNOPSIS
 
